==> ui-18.5.2.tgz: package/components/checkbox/CheckboxGroupRenderer.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { useGeneralContext, useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { useFormControl } from '../form';
import { useComponentConfig } from '../root';
import { DCheckbox } from './Checkbox';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DCheckbox.GroupRenderer' });
export function DCheckboxGroupRenderer(props) {
    const { dFormControl, dList, dModel, dVerticalCenter = false, dDisabled = false, dRender, onModelChange, } = useComponentConfig(COMPONENT_NAME, props);
    //#region Context
    const { gDisabled } = useGeneralContext();
    //#endregion
    const formControlInject = useFormControl(dFormControl);
    const [value, changeValue] = useDValue([], dModel, onModelChange, undefined, formControlInject);
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return dRender(dList.map((item, index) => (_jsx(DCheckbox, Object.assign({ dVerticalCenter: dVerticalCenter, dDisabled: item.disabled || disabled, dInputRender: (el) => cloneHTMLElement(el, {
            ['data-form-item-label-for']: index === 0,
        }), dModel: value.includes(item.value), onModelChange: (checked) => {
            changeValue((draft) => {
                if (checked) {
                    draft.push(item.value);
                }
                else {
                    draft.splice(draft.findIndex((v) => v === item.value), 1);
                }
            });
        } }, { children: item.label }), item.value))));
}

==> ui-18.5.5.tgz: package/components/checkbox/CheckboxGroupRenderer.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { useGeneralContext, useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { useFormControl } from '../form';
import { useComponentConfig } from '../root';
import { DCheckbox } from './Checkbox';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DCheckbox.GroupRenderer' });
export function DCheckboxGroupRenderer(props) {
    const { dFormControl, dList, dModel, dDisabled = false, dRender, onModelChange } = useComponentConfig(COMPONENT_NAME, props);
    //#region Context
    const { gDisabled } = useGeneralContext();
    //#endregion
    const formControlInject = useFormControl(dFormControl);
    const [value, changeValue] = useDValue([], dModel, onModelChange, undefined, formControlInject);
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return dRender(dList.map((item, index) => (_jsx(DCheckbox, Object.assign({ dDisabled: item.disabled || disabled, dInputRender: (el) => cloneHTMLElement(el, {
            ['data-form-item-label-for']: index === 0,
        }), dModel: value.includes(item.value), onModelChange: (checked) => {
            changeValue((draft) => {
                if (checked) {
                    draft.push(item.value);
                }
                else {
                    draft.splice(draft.findIndex((v) => v === item.value), 1);
                }
            });
        } }, { children: item.label }), item.value))));
}
